<li>
    <a href="/" class="main">Home</a>
</li>
<li>
    <a href="/accounts/profile">
    {% if user.picture_url %}
    <img src="{{ user.picture_url }}" class="profile-picture-icon menu-icon" alt=""/>
    {% else %}
    <img src="/static/images/profile-default-icon.png" class="profile-picture-icon menu-icon" alt=""/>
    {% end %}
    {{ user.username[:14] }}{% if len(user.username) > 14 %}...{% end %}
    </a>
</li>
<li><a href="/accounts/logout">Log out</a></li>
