<div class="row">
    <div class="eight columns">
        <h1>It works!</h1>
        <h3>Welcome to Airy</h3>
        <p>
            Airy is a new Web application development framework.
        </p>
        <p>
            Contrast to most currently available frameworks Airy
            doesn't use the standard notion of HTTP requests and pages.
        </p>
        <p>
            Instead, it makes use of WebSockets (via Socket.io) and
            provides a set of tools to let you focus on the interface,
            not content delivery.
        </p>
        <p>
            This project comes with a useful <strong>users</strong>
            app. You can extend it, and use an example to build new apps.
        </p>
        <p>
            Airy is created by Leto, a startup agency based in London, UK.
        </p>
        <p>
            Check out Leto website for help and support: <a href="http://letolab.com">http://letolab.com</a>
        </p>
    </div>
</div>

